Make mp3_get_file_info() static.
[paraslash.git] / filter.c
index d1f88539b946b571339902bbc9d950a2555365a8..939f9b56501f99cdeb4fa11695cb1c49c0e3e5c0 100644 (file)
--- a/filter.c
+++ b/filter.c
@@ -1,21 +1,10 @@
 /*
 /*
- * Copyright (C) 2005-2007 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2005-2008 Andre Noll <maan@systemlinux.org>
  *
  *
- *     This program is free software; you can redistribute it and/or modify
- *     it under the terms of the GNU General Public License as published by
- *     the Free Software Foundation; either version 2 of the License, or
- *     (at your option) any later version.
- *
- *     This program is distributed in the hope that it will be useful,
- *     but WITHOUT ANY WARRANTY; without even the implied warranty of
- *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *     GNU General Public License for more details.
- *
- *     You should have received a copy of the GNU General Public License
- *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Licensed under the GPL v2. For licencing details see COPYING.
  */
  */
-/** \file filter.c the stand-alone filter program */
+
+/** \file filter.c The stand-alone filter program. */
 
 #include "para.h"
 
 
 #include "para.h"
 
 #include "stdout.h"
 #include "error.h"
 
 #include "stdout.h"
 #include "error.h"
 
/** init the array of errors for para_filter */
 INIT_FILTER_ERRLISTS;
 
 INIT_FILTER_ERRLISTS;
 
-/** the task that reads from stdin */
+/** The task that reads from stdin. */
 static struct stdin_task stdin_task_struct;
 static struct stdin_task stdin_task_struct;
-/** pointer to the stdin task */
+/** pointer to the stdin task. */
 static struct stdin_task *sit = &stdin_task_struct;
 
 static struct stdin_task *sit = &stdin_task_struct;
 
-/** the task that filters the data */
+/** The task that filters the data. */
 static struct filter_chain filter_chain_struct;
 static struct filter_chain filter_chain_struct;
-/** pointer to the filter chain */
+/** Pointer to the filter chain. */
 static struct filter_chain *fc = &filter_chain_struct;
 
 static struct filter_chain *fc = &filter_chain_struct;
 
-/** the task that writes converted data to stdout */
+/** The task that writes converted data to stdout. */
 static struct stdout_task stdout_task_struct;
 static struct stdout_task stdout_task_struct;
-/** pointer to the stdout task */
+/** Pointer to the stdout task. */
 static struct stdout_task *sot = &stdout_task_struct;
 
 static struct stdout_task *sot = &stdout_task_struct;
 
-/** gengetopt struct that holds the command line args */
+/** Gengetopt struct that holds the command line args. */
 static struct filter_args_info conf;
 
 INIT_STDERR_LOGGING(conf.loglevel_arg);
 
 static struct filter_args_info conf;
 
 INIT_STDERR_LOGGING(conf.loglevel_arg);
 
-static void filter_event_handler(struct task *t)
-{
-       PARA_NOTICE_LOG("%s\n", PARA_STRERROR(-t->ret));
-       unregister_task(t);
-}
-
 static void open_filters(void)
 {
 static void open_filters(void)
 {
+       int i;
        struct filter_node *fn;
 
        struct filter_node *fn;
 
-       list_for_each_entry(fn, &fc->filters, node) {
-               fn->filter->open(fn);
-               PARA_INFO_LOG("opened %s filter\n", fn->filter->name);
+       FOR_EACH_FILTER_NODE(fn, fc, i) {
+               struct filter *f = filters + fn->filter_num;
+               f->open(fn);
+               PARA_INFO_LOG("opened %s filter\n", f->name);
                fc->outbuf = fn->buf;
                fc->out_loaded = &fn->loaded;
        }
                fc->outbuf = fn->buf;
                fc->out_loaded = &fn->loaded;
        }
@@ -71,39 +56,37 @@ static void open_filters(void)
 
 static int init_filter_chain(void)
 {
 
 static int init_filter_chain(void)
 {
-       int i, filter_num;
+       int i, ret;
        struct filter_node *fn;
 
        struct filter_node *fn;
 
-       INIT_LIST_HEAD(&fc->filters);
-
+       if (!conf.filter_given)
+               return -E_NO_FILTERS;
+       fc->num_filters = conf.filter_given;
+       fc->filter_nodes = para_malloc(fc->num_filters * sizeof(struct filter_node));
        fc->inbuf = sit->buf;
        fc->in_loaded = &sit->loaded;
        fc->inbuf = sit->buf;
        fc->in_loaded = &sit->loaded;
-       fc->input_eof = &sit->eof;
-       fc->eof = 0;
-       fc->output_eof = &sot->eof;
-       fc->task.private_data = fc;
+       fc->input_error = &sit->task.error;
+       fc->task.error = 0;
+       fc->output_error = &sot->task.error;
        fc->task.pre_select = filter_pre_select;
        fc->task.pre_select = filter_pre_select;
-       fc->task.event_handler = filter_event_handler;
        sprintf(fc->task.status, "filter chain");
 
        sprintf(fc->task.status, "filter chain");
 
-       for (i = 0; i < conf.filter_given; i++) {
+       FOR_EACH_FILTER_NODE(fn, fc, i) {
                char *fa = conf.filter_arg[i];
                char *fa = conf.filter_arg[i];
-               fn = para_calloc(sizeof(struct filter_node));
-               filter_num = check_filter_arg(fa, &fn->conf);
-               if (filter_num < 0) {
-                       free(fn);
-                       return filter_num;
-               }
+               fn = fc->filter_nodes + i;
+               ret = check_filter_arg(fa, &fn->conf);
+               if (ret < 0)
+                       goto err;
+               fn->filter_num = ret;
                fn->fc = fc;
                INIT_LIST_HEAD(&fn->callbacks);
                fn->fc = fc;
                INIT_LIST_HEAD(&fn->callbacks);
-               fn->filter = &filters[filter_num];
-               PARA_DEBUG_LOG("adding %s to filter chain\n", fn->filter->name);
-               list_add_tail(&fn->node, &fc->filters);
+               PARA_DEBUG_LOG("filter #%d: %s\n", i, filters[fn->filter_num].name);
        }
        }
-       if (list_empty(&fc->filters))
-               return -E_NO_FILTERS;
        open_filters();
        return 1;
        open_filters();
        return 1;
+err:
+       free(fc->filter_nodes);
+       return ret;
 }
 
 static int parse_config(int argc, char *argv[])
 }
 
 static int parse_config(int argc, char *argv[])
@@ -121,7 +104,13 @@ static int parse_config(int argc, char *argv[])
                free(home);
        }
        if (!stat(cf, &statbuf)) {
                free(home);
        }
        if (!stat(cf, &statbuf)) {
-               if (filter_cmdline_parser_configfile(cf, &conf, 0, 0, 0))
+               struct filter_cmdline_parser_params params = {
+                       .override = 0,
+                       .initialize = 0,
+                       .check_required = 0,
+                       .check_ambiguity = 0
+               };
+               if (filter_cmdline_parser_config_file(cf, &conf, &params))
                        return -E_FILTER_SYNTAX;
        }
        if (!conf.list_filters_given)
                        return -E_FILTER_SYNTAX;
        }
        if (!conf.list_filters_given)
@@ -136,21 +125,21 @@ static int parse_config(int argc, char *argv[])
 }
 
 /**
 }
 
 /**
- * para_filter's main function.
+ * The main function of para_filter.
  *
  *
- * para_filter reads data from stdin, converts it by using a chain
+ * Para_filter reads data from stdin, converts it by using a chain
  * of filters (specified on the command line) and writes the resulting
  * data to stdout.
  *
  * of filters (specified on the command line) and writes the resulting
  * data to stdout.
  *
- * \param argc number of command line options
- * \param argv vector of arguments
+ * \param argc Number of command line options.
+ * \param argv Vector of arguments.
  *
  * \return \a EXIT_SUCCESS on success, EXIT_FAILURE on errors.
  */
 int main(int argc, char *argv[])
 {
        int ret;
  *
  * \return \a EXIT_SUCCESS on success, EXIT_FAILURE on errors.
  */
 int main(int argc, char *argv[])
 {
        int ret;
-       struct sched s;
+       static struct sched s;
 
        stdin_set_defaults(sit);
        sit->buf = para_malloc(sit->bufsize),
 
        stdin_set_defaults(sit);
        sit->buf = para_malloc(sit->bufsize),
@@ -166,18 +155,18 @@ int main(int argc, char *argv[])
        stdout_set_defaults(sot);
        sot->buf = fc->outbuf;
        sot->loaded = fc->out_loaded;
        stdout_set_defaults(sot);
        sot->buf = fc->outbuf;
        sot->loaded = fc->out_loaded;
-       sot->input_eof = &fc->eof;
+       sot->input_error = &fc->task.error;
 
 
-       register_task(&sot->task);
-       register_task(&fc->task);
        register_task(&sit->task);
        register_task(&sit->task);
+       register_task(&fc->task);
+       register_task(&sot->task);
        s.default_timeout.tv_sec = 1;
        s.default_timeout.tv_usec = 0;
        s.default_timeout.tv_sec = 1;
        s.default_timeout.tv_usec = 0;
-       ret = sched(&s);
+       ret = schedule(&s);
+       close_filters(fc);
 out:
        free(sit->buf);
 out:
        free(sit->buf);
-       close_filters(fc);
        if (ret < 0)
        if (ret < 0)
-               PARA_EMERG_LOG("%s\n", PARA_STRERROR(-ret));
+               PARA_EMERG_LOG("%s\n", para_strerror(-ret));
        return ret < 0? EXIT_FAILURE : EXIT_SUCCESS;
 }
        return ret < 0? EXIT_FAILURE : EXIT_SUCCESS;
@@ -1,21 +1,10 @@
 #include "error.h"
 
-/** init the array of errors for para_filter */
+/** Initialize the array of errors for para_filter. */
 INIT_FILTER_ERRLISTS;
 
 }